corrected offline kernel compilation on hipcc path

1. hipgenisa.sh now adds int main(){} during kernel compilation. User does not have to put it there
2. Renamed vcpy_isa.cpp to vcpy_kernel.cpp
3. Removed vcpy_isa.cu as the kernel code should be common for both paths
4. Changed Makefile and runkernel.cpp to work with above changes

Change-Id: I9f8c84706b44bb500bc493a68e959762b55a0142


[ROCm/hip commit: 4f8c45d05a]
This commit is contained in:
Aditya Atluri
2016-09-02 13:17:17 -05:00
parent 5820670910
commit 6e9fc7523d
5 changed files with 15 additions and 17 deletions
@@ -0,0 +1,8 @@
#include<hip_runtime.h>
__global__ void hello_world(hipLaunchParm lp, float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx];
}